@@ -16,7 +16,7 @@ use Locale::Maketext::Simple    Style => 'gettext';
 
 ### solaris has silly /bin/tar output ###
 use constant ON_SOLARIS     => $^O eq 'solaris' ? 1 : 0;
-use constant ON_NETBSD      => $^O eq 'netbsd' ? 1 : 0;
+use constant ON_NETBSD      => $^O =~ m!^(netbsd|minix)$! ? 1 : 0;
 use constant ON_OPENBSD     => $^O =~ m!^(openbsd|bitrig)$! ? 1 : 0;
 use constant ON_FREEBSD     => $^O =~ m!^(free|midnight|dragonfly)(bsd)?$! ? 1 : 0;
 use constant ON_LINUX       => $^O eq 'linux' ? 1 : 0;
@@ -48,7 +48,7 @@ use vars qw[$VERSION $PREFER_BIN $PROGRAMS $WARN $DEBUG
             $_ALLOW_BIN $_ALLOW_PURE_PERL $_ALLOW_TAR_ITER
          ];
 
-$VERSION            = '0.78';
+$VERSION            = '0.82';
 $PREFER_BIN         = 0;
 $WARN               = 1;
 $DEBUG              = 0;
@@ -135,7 +135,7 @@ CMD: for my $pgm (qw[tar unzip gzip bunzip2 uncompress unlzma unxz]) {
       $PROGRAMS->{$pgm} = $unzip;
       next CMD;
     }
-    if ( $pgm eq 'unzip' and ON_FREEBSD ) {
+    if ( $pgm eq 'unzip' and ( ON_FREEBSD || ON_LINUX ) ) {
       local $IPC::Cmd::INSTANCES = 1;
       ($PROGRAMS->{$pgm}) = grep { _is_infozip_esque($_) } can_run($pgm);
       next CMD;
@@ -145,13 +145,6 @@ CMD: for my $pgm (qw[tar unzip gzip bunzip2 uncompress unlzma unxz]) {
       ($PROGRAMS->{$pgm}) = grep { m!/usr/pkg/! } can_run($pgm);
       next CMD;
     }
-    if ( $pgm eq 'unzip' and ON_LINUX ) {
-      # Check if 'unzip' is busybox masquerading
-      local $IPC::Cmd::INSTANCES = 1;
-      my $opt = ON_VMS ? '"-Z"' : '-Z';
-      ($PROGRAMS->{$pgm}) = grep { scalar run(command=> [ $_, $opt, '-1' ]) } can_run($pgm);
-      next CMD;
-    }
     if ( $pgm eq 'tar' and ( ON_OPENBSD || ON_SOLARIS || ON_NETBSD ) ) {
       # try gtar first
       next CMD if $PROGRAMS->{$pgm} = can_run('gtar');
@@ -822,8 +815,11 @@ sub _untar_at {
     ### if A::T's version is 0.99 or higher
     if( $self->is_tgz ) {
         my $use_list = { 'Compress::Zlib' => '0.0' };
+        {
+           local $@;
            $use_list->{ 'IO::Zlib' } = '0.0'
-                if $Archive::Tar::VERSION >= '0.99';
+                if eval { Archive::Tar->VERSION('0.99'); 1 };
+        }
 
         unless( can_load( modules => $use_list ) ) {
             my $which = join '/', sort keys %$use_list;
